/**
 * 充值第三方货币界面(网游开发者接口)
 */
DGC.View.DChargeCommit =  $.inherits(DGC.View, {

    title:"TITLE_NET_CHARGE_GAME",

    baseId: 'charge-commit-user-view',

    payWay: undefined,

    /**
     * 第三方货币信息
     */
    chargeInfo : undefined,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        //缓存已经充值成功的账号
        this.chargedAccount = [];

        //电信/联通/移动卡号密码位数限制
        this.limitConifg = {
            //移动
            v3:{
                cardNumber: 17,
                password: 18
            },
            //联通
            v4:{
                cardNumber: 15,
                password: 19
            },
            //电信
            v5:{
                cardNumber: 19,
                password: 18
            }
        }

        //设置标题
        this.el.find(".charge-type-tip").html($.format(resName.TEXT_CHARGECOMMIT_PAYWAY,["<span>\""+ this.payWay.name +"\"</span>"]));

        //设置empty内容
        var cardField = this.el.find("input[name='cardNumber']"),
            passField = this.el.find("input[name='password']"),
            maxConfig = this.limitConifg['v'+this.payWay.identifier],
            helpEl = this.el.find(".help-desc-msg");


        //易宝需要卡号 /密码
        if(this.isNeedCardInfo(this.payWay.identifier)){
            cardField.attr("maxlength", maxConfig.cardNumber);
            passField.attr("maxlength", maxConfig.password);
            cardField.attr("placeholder",$.format(resName.TEXT_CHARGECOMMIT_CARD_NUM_TIP,[maxConfig.cardNumber]));
            passField.attr("placeholder",$.format(resName.TEXT_CHARGECOMMIT_CARD_PASS_TIP,[maxConfig.password]));
            cardField.keypress(DGC.Common.onlyAllowNumber);
            passField.keypress(DGC.Common.onlyAllowNumber);
            helpEl.text(resName.TEXT_NET_CHARGE_COMMIT_HELP_DESC);
        //其他支付，则隐藏卡号/密码表单
        }else{
            this.el.find(".field-wrap:gt(0)").hide();
            helpEl.text(resName.TEXT_CHARGE_YIBAO_COMMIT_HELP_DESC);
        }

        //渲染支付列表
        this.renderPayValues();

        //充值按钮
        $("#d-charge-btn").bind(DGC.Common.E_TAP_DOWN,DGC.Common.buttonTapDownHandler)
            .bind(DGC.Common.E_TAP_UP,DGC.Common.buttonTapEndHandler)
            .bind("tap", { context: this }, this.payActionHanlder);

    },

    /**
     * 是否需要卡号/密码(易宝)
     * @param {Number} paymethod 充值方式枚举
     */
    isNeedCardInfo: function(paymethod){
        switch(paymethod){
             /*易宝移动，联通，电信*/
             case 3:
             case 4:
             case 5:
                return true;
                break;
        }

        return false;
    },

    /**
     * 渲染可选金额项
     */
    renderPayValues : function(){
        var selectValue = "{0}"+ resName.TEXT_MYPURSE_UNIT,
            options = this.payWay.list_values,
            selectEl = this.el.find(".select-wrap"),
            nOptions = [];

        //下拉选项框拼接结构
        for (var i = 0; i < options.length; i++) {
              nOptions.push({
                   text: $.format(selectValue,[ options[i] ]),
                   value: String(options[i])
              });
        };

        this.cacheOptions = nOptions;

        //默认选择项
        this.el.find(".select-text").text($.format(selectValue, [  options[0] ] ));
        this.selectedMoney = parseFloat(options[0], 10);

        selectEl.bind("tap", { context: this }, function(event){
            var context = event.data.context;
            //获得当期选则的 index
            for(var index = 0 ; index < context.cacheOptions.length; index++){
                if(parseFloat(context.cacheOptions[index].value, 10) == context.selectedMoney ){
                    break;
                }
            }
            DGC.ActionUtil.commonSelect(DGC.Service.Messages.SHOW_CHARGE_VALUE, context.cacheOptions, index);
        });

    },

    /**
     * 选择金额回调
     */
    chargeValueSelected: function(selectItem){
        this.selectedMoney = parseFloat(selectItem.value);
        this.el.find(".select-text").text(selectItem.text);
    },

    /**
     * 充值按钮
     */
    payActionHanlder : function(event){
        var context = event.data.context,
            DAU = DGC.ActionUtil,
            payModel = context.action.model['pay'],
            account = context.el.find("input[name='cardNumber']").val(),
            password = context.el.find("input[name='password']").val(),
            money = context.selectedMoney;


        var chargeObj = {
            paymethod: context.payWay.identifier,
            recharge:  money  /*实际充值金额*/
        }

        //“具体某一渠道充值”界面，点击充值(网游版)
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.NET_EVENT_PAYMENT_CHARGE_DETAIL_CHARGE,
            {
                'game_id': window.sdk.game.id,
                'user_id': window.sdk.player.id,
                'channel_id': window.sdk.channel_id,
                'charge_channel': DGC.Event.Util.getPayEvent(chargeObj.paymethod)
            }
        );

        //易宝支付验证
        if(context.isNeedCardInfo(context.payWay.identifier) ){
            //卡号不能为空
            if($.isEmpty(account)){
                DAU.showTipMsg(resName.TIP_CHARGECOMMIT_ACCOUNT_NOT_NULL);
                return false;
            }

            //卡密不能为空
            if($.isEmpty(password)){
                DAU.showTipMsg(resName.TIP_PASSWORD_NOT_NULL);
                return false;
            }

            //验证卡密位数
            var cardVerify = context.limitConifg['v'+context.payWay.identifier];
            if(account.length  != cardVerify.cardNumber){
                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_INVAIL_CARDNUM, [ cardVerify.cardNumber ]));
                return false;
            }

            if(password.length != cardVerify.password){
                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_INVAIL_PASSWORD, [ cardVerify.password ]));
                return false;
            }

            if(context.isChargedAccount(account, password)){
                DAU.log(resName.TIP_CHARGE_PAY_COMMIT_USED_CARD);
                DAU.showTipMsg(resName.TIP_CHARGE_PAY_COMMIT_USED_CARD);
                return false;
            }

            $.extend(chargeObj,{
                card_no: account,
                card_pwd: password
            });
        }

        payModel.executePay( 8 /*网游道具购买*/, $.extend(chargeObj, context.chargeInfo));
    },

    /**
     * 是否为充值过的卡密
     * @params cardNo {String} 卡号
     * @params password {String} 密码
     */
    isChargedAccount: function(cardNo, password){
        for(var i = 0 ; i < this.chargedAccount.length; i++){
            var charged = this.chargedAccount[i];
            if(charged.card_no == cardNo && charged.card_pwd == password ){
                return true;
            }
        }

        return false;
    },

    /**
     * 支付第三方货币结果响应后进行结果操作
     * @param {Number} paymethod Feed API 支付方式
     * @param {Boolean} result 充值结果
     * @param {object} detail 充值方式以及提示
     */
    payCurrenyResult: function(result, detail , extras){
        var DAU = DGC.ActionUtil;
        if(detail.paymethod == 6 /*支付宝*/ || detail.paymethod == 23 /*财付通*/){
            //支付宝页面跳转
            if(result){
                //支付宝下单成功->打开新页面
                DAU.openWebView(detail.payment_url, true);
            }
        //易宝
        }else if(detail.paymethod >= 3 && detail.paymethod <= 5 ){
            if(result){
                //缓存已下单成功的卡密
                this.chargedAccount.push({
                    card_no: detail.card_no,
                    card_pwd: detail.card_pwd
                });
                DAU.showTipMsg($.format(resName.TIP_CHARGECOMMIT_YIBAO_SUCCESS, [detail.id]),function(){
                    //返回游戏
                    DAU.returnToGame();
                });
            }
        }

        //通知SDK
        this.action.model['pay'].payOrderNotify({
            result: result ,
            type: 3 /*网游货币*/ ,
            detail: detail,
            extras: extras
        });
    },

    /**
     * 本地充值第三方货币显示结果
     */
    payByLocalResult : function(result, detail){
        var DAU = DGC.ActionUtil;
        if(result){
            DAU.localTipMsg($.format(resName.TIP_DCHARGECOMMIT_LOCAL_SUCCESS,[detail.recharge]));
        }else{
            DAU.localTipMsg(resName.TIP_DCHARGECOMMIT_LOCAL_FAIL);
        }

        DGC.Application.goBack();
    }

});
