/**
 * 本地游戏信息
 */
DGC.View.LocalGames =  $.inherits(DGC.View, {

    baseId : 'localgames-view',


    /**
     * 别名
     */
    alias: 'LocalGames',

    /**
     * 根视图
     */
    isSub: false,

    /**
     * 标题文字
     * @type Boolean
     */
    title : 'A_TITLE_GAMES',

    /**
     * 数据存储
     * @type String
     */
    temData : null,


    adScrollTask: 0,

    /**
     * 标识列表是否已经渲染
     * @type Boolean
     */
    localRendered:false,

    /**
     * 视图初始化函数
     */
    viewReady: function(){
        this.viewTpl = {
            GAME:'#lg-game-tpl'
        }

        this.action.model['game'].queryLocalGameList();

        //支持滚动广告展示
        this.adPlugin = new DGC.ViewPlugin.ScrollAds(this);
        this.adPlugin.start();

        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_GAMES);

    },

    //渲染localgame页面
    findLocalGame : function(gameList){

        //过滤包名为空的数据
        for(var i= gameList.length - 1; i >= 0; i--){
            var game = gameList[i];
            if( game['bundle_id'] == null || game['bundle_id'] == ''){
                gameList.splice(i,1);
            }
        }

        this.temData = gameList;

        var params = new Array();
        for(var key in gameList){
            var game = gameList[key];
            params.push(game.bundle_id);
        }
        //获取本地游戏状态
        DGC.ActionUtil.getGameState(params);
    },

    //加上游戏状态一起渲染
    findLocalGameState : function(gameListState){
        if(this.localRendered) return false;

        var gameList = this.temData,
            context = this;

        for(var key in gameList){
            var game = gameList[key];
            $.extend(game, {player_count_text: DH.getPlayedDesc(game.player_count)});
            $.extend(game, {state: gameListState.data.states[key]});
            var weizhi = game.icon_url.lastIndexOf("/");
            var url = game.icon_url.substr(0,weizhi);
            var png = game.icon_url.substr(weizhi);
            var grays_icon_url = url+"/grays"+png;
            $.extend(game,{grays_icon_url:grays_icon_url});
            if(gameListState.data.states[key]){
                var state_text = resName.TEXT_LOCALGAMES_PLAYGAME;
            }else{
                var state_text = resName.TEXT_LOCALGAMES_DOWNLOAD;
            }
            $.extend(game,{state_text:state_text});

             //加载游戏ICON
            if(game.hasOwnProperty("enable_download") && !game.enable_download && !game.state){
                $.extend(game, {disable: false, show_icon: game.grays_icon_url} ); /*disable禁止下载*/
            }else{
                $.extend(game, {disable: true, show_icon: game.icon_url } ); /*disable允许下载*/
            }
        }

        $(".total-games-bar").html($.format(resName.TITLE_LOCALGAMES_GAMES_TOATAL,[gameList.length]));

        ////渲染Game 延迟渲染
        $.timerEach(gameList,function(game){
            var itemEl = $(context.renderByTpl(context.viewTpl.GAME, game));
            itemEl.bind(DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler)
                  .bind(DGC.Common.E_TAP_UP, DGC.Common.listTapEndHandler);

            //玩游戏
            itemEl.filter('.play').bind('tap', context.playGameHandler);
            //下载游戏
            itemEl.filter('.download').bind('tap', context.downloadGameHandler);

            $(".localgames-list").append(itemEl);

            //加载完成后，替换图标
            context.loadImages({ id: game.id,  url: game.show_icon}, function(img, data){
                var item = $("a[data-id='"+ data.id +"']");
                item.find(".default-game").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");
            });
        }, $.emptyFn);

        this.localRendered = true;
    },

    /**
     * 玩游戏
     * @return {Boolean}
     */
    playGameHandler :function(){
        var id = $(this).attr('data-id'),
            game_name = $(this).attr('data-game-name'),
            bundle_id = $(this).attr('data-name');

        //正在玩的游戏，不能启动
        if(window.sdk.package_name == bundle_id ){
            return false;
        }

        //记录用户点击事件、玩游戏
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_GAMES_PLAY,
            {
                'game_id':window.sdk.game.id,
                'user_id':window.sdk.player.id,
                'target_game_id':id,
                'target_game_name':game_name
            }
        );


        DGC.ActionUtil.startGame(bundle_id);
    },

    /**
     * 下载游戏
     */
    downloadGameHandler :function(){
        var id = $(this).attr('data-id'),
            game_name = $(this).attr('data-game-name'),
            bundle_id =  $(this).attr('data-name'),
            download_url = $(this).attr('data-url');

        //记录用户点击事件、下载游戏
        DGC.ActionUtil.recordUserAction(
            DGC.Event.EventId.EVENT_GAMES_DOWNLOAD,
            {
                'game_id':window.sdk.game.id,
                'user_id':window.sdk.player.id,
                'target_game_id':id,
                'target_game_name':game_name,
                'target_game_url': download_url
            }
        );

        DGC.ActionUtil.download(download_url, bundle_id);//下载游戏
    },


   /**
    * 视图销毁时，移除事件监听
    */
   onDestory : function(){
       this.adPlugin.destory();
    }
});