/**
 * 玩过的游戏视图
 */
DGC.View.PlayedGames =  $.inherits(DGC.View, {

    baseId : 'playedgames-view',

    /**
     * 别名
     */
    alias: 'PlayedGames',

    /**
     * 标题文字
     * @type Boolean
     */
    title : false,

    player: undefined,

    nextPageCur:undefined,

    /**
     * 滚动延迟加载
     */
    loadMoreTask: 0,

    /**
     * 广告滚动Task
     */
    adScrollTask: 0,

    /**
     * 视图初始化函数
     */
    viewReady: function(){

        this.viewTpl = {
            LIST_ITEM:"#pg-list-tpl"
        };

        //加载完成后设置状态标题及内容
        var isMe = (window.sdk.player.nickname == this.player.nickname );

         //设置标题
        this.setTitle($.format(resName.A_TITLE_ME_PLAYEDGAMES,[ isMe ?
            resName.A_TITLE_ME_PLAYEDGAMES_ME: this.player.nickname ]));

        //设置玩过游戏的总数
        var text = $.format(resName.TEXT_PLAYGAMES_STATUS_TITLE,[ isMe ?
            resName.TEXT_PLAYGAMES_STATUS_ME: this.player.nickname , this.player.total_games]);

        //加载模板渲染内容
        $("#pg-gamesnum").text(text);

        //查询默认列表
        this.action.model['me'].queryPlayedGames(this.player.id);

        //预绑定
        this.prevBindGameDetial(true);

        //绑定页面滑动
        $(window).bind("scroll", { context: this }, this.scrollLoadMoreGames);

        /*
        this.el.find(".list-item").bind('tap', {context: this}, function(event) {
            var context = event.data.context;
            context.action.setView('GameInfo');
        });
        */

         //支持滚动广告展示
        this.adPlugin = new DGC.ViewPlugin.ScrollAds(this);
        this.adPlugin.start();


        //记录页面访问次数
        DGC.ActionUtil.recordPageCount(DGC.Event.PageId.SKYNET_PAGE_ME_GAMES);

    },

    /**
     * 绑定或取消绑定游戏详细信息
     */
    prevBindGameDetial : function(bindStatus){
        var fn = bindStatus ? "live" : "die";
        var games = $("#pg-game-list .list-item:not(.empty-item)");
        games[fn](DGC.Common.E_TAP_UP,DGC.Common.listTapEndHandler);
        games[fn](DGC.Common.E_TAP_DOWN, DGC.Common.listTapDownHandler);

        //支持排行榜和成就，则跳转
        if(DH.isSupportHighscoresAchieve()){
            games[fn]("tap", { context : this}, this.showGameDetail);
        }
    },


    /**
     * 滚动时监听
     */
    scrollLoadMoreGames : function(event){
        var context = event.data.context;

        //滚到页面底端
        if(Math.abs($(window).scrollTop() -( $(document).height() - $(window).height())) <= 10){
            if(context.nextPageCur){
                clearTimeout(context.loadMoreTask);
                context.loadMoreTask = setTimeout(function(){
                    context.action.model['me'].queryPlayedGames(context.player.id, context.nextPageCur);
                }, DGC.Common.DELAY_SCROLL_LOADER);
            }
        }
    },

    /**
     * 渲染玩过的游戏列表
     * @param {Array<Object>} gamesInfo 游戏列表
     * @param {Boolean} isMore 是否为二次加载
     */
    renderPlayedGames : function(gamesInfo , isMore){
        var gameList = gamesInfo.data,
            delayIcons = [];

        if(gameList.length == 0 && !isMore ){
            $("#pg-game-list").html(DGC.Common.getEmptyListItemHtml(resName.TEXT_PLAYGAMES_EMPTY_GAMES));
        }else{
            for (var i = 0; i < gameList.length; i++) {
                var game = gameList[i];
                //添加文本字段
                game.player_count_text =  DH.getPlayedDesc(game.player_count);

                //判断是否存在图标
                if(!$.isEmpty(game.icon_url)){
                    delayIcons.push({
                        url : game.icon_url,
                        id : game.id
                    });
                }
            }

            $("#pg-game-list").append(this.renderByTpl(this.viewTpl.LIST_ITEM, gameList));

            //延迟加载图标
            if(delayIcons.length > 0){
                this.loadImages(delayIcons, function(img, data){
                    var item = $("div[data-key='" + data.id + "']");
                    item.find(".default-game").replaceWith("<img src='" + img.src +"'><div class='mask'></div>");;
                });
            }

        }

        //缓存下一页的游标
        this.nextPageCur = gamesInfo.next_cursor ?  gamesInfo.next_cursor : null;
    },

    showGameDetail : function(event){
        var context = event.data.context,
            me = $(this),
            id,
            name;
        id = me.attr("data-key");
        name = $.trim(me.find('h1').text());

        if(context.player.id == window.sdk.player.id){
            //记录点：“我玩过的游戏”界面，点击 某一款游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_ME_GAMES_VIEW,
                {
                    'game_id':window.sdk.game.id,
                    'target_game_id':id
                }
            );
        }else{
            //记录点：：“玩家-­‐>TA 玩过的游戏”界面，点击 具体某个游戏
            DGC.ActionUtil.recordUserAction(
                DGC.Event.EventId.EVENT_PLAYER_GAMES_VIEW,
                {
                    'game_id':window.sdk.game.id,
                    'player_id':context.player.id,
                    'target_game_id':id
                }
            );
        }

        context.action.setView('GameInfo',{
            title : name,
            gameId : id,
            player : context.player
        });
    },

    /**
     * 视图销毁时，移除事件监听
     */
    onDestory : function(){
        this.adPlugin.destory();
        this.adPlugin = null;

        this.prevBindGameDetial(false);
        $(window).unbind("scroll", this.scrollLoadMoreGames);
    }

});
