﻿/**
 * 部署/调试模式开关
 */
var DEBUG = {

    /**
     * 当前调试模式
     */
    debugModel : 0,

    /**
     * 产品部署模式
     * @type Number
     */
    PRODUCT_MODEL  : 0,

    /**
     * Web调试模式
     * @type Number
     */
    WEB_DEBUG_MODEL: 1,

    /**
     * Android调试模式
     * @type Number
     */
    DEVICE_MODEL  : 2,

    /**
     * 判断是否为Web部署模式
     */
    isWebModel : function(){
        return DEBUG.debugModel == DEBUG.WEB_DEBUG_MODEL;
    },

    /**
     * 判断是否为设备联调模式
     */
    isDeviceModel: function(){
        return DEBUG.debugModel == DEBUG.DEVICE_MODEL;
    },

    /**
     * 判断是否为部署模式
     */
    isProductModel : function(){
        return DEBUG.debugModel == DEBUG.PRODUCT_MODEL;
    }

};

/**
 * Mock(WebModel)
 */
(function(w){
    if(DEBUG.isWebModel()){
        w.NativeInterface = {

            /**
             * 始终使用最新目录SVN
             */
            rootVersion: '1.5.0-0000',

            action : function(json){
                /*获取mock数据封装*/
                function getFile(url, callback){
                    var xhr =  new XMLHttpRequest();
                    xhr.onreadystatechange = function(response){
                        if(xhr.readyState == 4){
                            if(xhr.status == 200){
                                callback(xhr);
                            }
                        }
                    };
                    xhr.open("GET", url);
                    xhr.send();
                }

                var requestBody = JSON.parse(json);

                if(requestBody.actionName == 'apiRequest'){
                     //渠道/url(.后缀)
                     //缺少桩文件
                    var url = requestBody.version || this.rootVersion  + '/test/' + requestBody.mockUrl;
                    var xhr =  new XMLHttpRequest();
                    xhr.onreadystatechange = function(response){
                        if(xhr.readyState == 4){
                            if(xhr.status == 200){
                                //包装桩数据
                                DGC.Application.actionCallback({
                                    success : true,
                                    data: JSON.parse(xhr.responseText),
                                    msgInfo : requestBody
                                });
                            }
                        }
                    };
                    xhr.open("GET", url);
                    xhr.send();
                }else if(requestBody.actionName == 'getInitInfo'){
                    getFile(this.rootVersion + "/test/init.json", function(xhr){
                         DGC.Application.initialize(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'getNativeInitInfo'){
                    getFile(this.rootVersion + "/test/device.json", function(xhr){
                         Loader.versionReady(JSON.parse(xhr.responseText));
                    });
                }else if( requestBody.actionName == "updateAvatar"){
                    //包装桩数据
                    DGC.Application.updateAvatarCallBack({
                        success : true
                    });
                }else if(requestBody.actionName == 'gameState'){
                    var json = { states:[false,false,false] };
                    DGC.Application.gameStateCallBack(json);
                }else if(requestBody.actionName == 'ledouAccountLogin'){
                    DGC.Application.notifyAccountReLogin({success:true});
                }else if(requestBody.actionName == 'offlineAchievement'){
                    getFile(this.rootVersion + "/test/achievement/offline.json", function(xhr){
                        DGC.Application.offlineAchieveCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'offlineLeaderboardMode'){
                    getFile(this.rootVersion + "/test/highscores/offlineboard.json", function(xhr){
                        DGC.Application.offlineBoardCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'offlineLeaderboard'){
                    getFile(this.rootVersion + "/test/highscores/offlinerank.json", function(xhr){
                        DGC.Application.offlineHighScoreCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'pay'){
                    getFile(this.rootVersion + "/test/payment/chargeresult.json", function(xhr){
                        DGC.Application.payCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'retrieveProductList'){
                    getFile(this.rootVersion + "/test/payment/productInfo.json", function(xhr){
                        DGC.Application.productListCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'getProductInfo'){
                    getFile(this.rootVersion +  "/test/payment/productInfoEntry.json", function(xhr){
                        DGC.Application.productInfoCallback(JSON.parse(xhr.responseText));
                    });
                }else if(requestBody.actionName == 'getIntegral'){
                    getFile(this.rootVersion +  "/test/payment/integralinfo.json", function(xhr){
                        DGC.Application.notifyIntegral(JSON.parse(xhr.responseText));
                    });
                }
            }
        }
    }
}(window));
